/*
 * ADC_functions.c
 *
 *  Created on: 26.jun.2009
 *      Author: Stian O. Moen
 *
 */


#include "ADC_functions.h"
#include "gpio.h"
#include "config.h"
#include "adc.h"
#include "intc.h"
#include "USART_functions.h"
#include "TC_functions.h"
#include "dsp.h"
#include "DSP_functions.h"


volatile signed int sample_nr;

A_ALIGNED dsp16_t sample[NUMBER_OF_SAMPLES];

volatile char sample_flag;

__attribute__((__interrupt__))
static void ADC_complete_irq(void)
{
	//gpio_clr_gpio_pin(AVR32_PIN_PA06);
	volatile avr32_adc_t *adc = &AVR32_ADC;

	if (sample_nr < NUMBER_OF_SAMPLES)
	{
		sample[sample_nr] = (adc->LCDR.ldata - dc_offset)*32;
		sample_nr++;
	}
	else
	{
		disable_sampling();
		// Clear the interrupt flag by reading the ADC_LCDR register.
		volatile unsigned short dummy = adc->LCDR.ldata;
	}

}

void init_ADC(void)
{
	// GPIO pin/adc-function map.
	static const gpio_map_t ADC_GPIO_MAP =
	  {
	    {AVR32_ADC_AD_0_PIN, AVR32_ADC_AD_0_FUNCTION},
	    {AVR32_ADC_AD_1_PIN, AVR32_ADC_AD_1_FUNCTION},
	  };

	// ADC IP registers address
	volatile avr32_adc_t *adc = &AVR32_ADC;

	// Assign and enable GPIO pins to the ADC function.-
	gpio_enable_module(ADC_GPIO_MAP, sizeof(ADC_GPIO_MAP) / sizeof(ADC_GPIO_MAP[0]));

	// configure ADC
	adc_configure(adc);

	// Enable the ADC channels.
	adc_enable(adc,SINGAL_IN_ADC_CHANNEL);
	//adc_enable(adc,SIGNAL_LEVEL_CHANNEL);

	//change prescaler settings to satisfy the meximum ADC frequency limitation
	adc->MR.prescal = 3; //prescaler = div16

	//enable hardware trigger from timer counter TIOA channel 0
	adc->MR.trgen = 1;
	adc->MR.trgsel = 0;

	Disable_global_interrupt();

	// Initialize interrupt vectors.

	// Register the ADC complete interrupt handler to the interrupt controller.
	INTC_register_interrupt(&ADC_complete_irq, AVR32_ADC_IRQ, AVR32_INTC_INT1);

	Enable_global_interrupt();


}

//This function will take one sample of the signal output of the variable gain
//amplifier and filter. It is not used.
signed short get_signal_sample(void)
{
	volatile avr32_adc_t *adc = &AVR32_ADC;
	adc_start(adc);
	return adc_get_value(adc, SINGAL_IN_ADC_CHANNEL);
}


//performs one ADC conversion for the reception detector analogue output.
signed short get_signal_level(void)
{
	volatile avr32_adc_t *adc = &AVR32_ADC;
	adc_enable(adc,SIGNAL_LEVEL_CHANNEL);
	DISABLE_ADC_INTERRUPT();
	adc_start(adc);
	return adc_get_value(adc, SIGNAL_LEVEL_CHANNEL);
}
