/*
 * EIC.functions.c
 *
 *  Created on: 02.jul.2009
 *      Author: Stian O. Moen
 */

#include "compiler.h"
#include "EIC_functions.h"
#include "eic.h"
#include "intc.h"
#include "gpio.h"
#include "RTC_functions.h"
#include "USART_functions.h"
#include "usart.h"
#include "DSP_functions.h"
#include "config.h"


//variables used by the external intertupt handler
time_variable_t current_pulse, previous_pulse;



//debug function: converts unsigned short to string.
void short_to_char(char *string, unsigned short number)
{
	string[0] = number/10000 + 0x30;
	number -= (number/10000)*10000;
	string[1] = number/1000 + 0x30;
	number -=(number/1000)*1000;
	string[2] = number/100	+ 0x30;
	number -= (number/100)*100;
	string[3] = number/10 	+ 0x30;
	number -= (number/10)*10;
	string[4] = number 	+ 0x30;
	string[5] = '\0';
}


//Interrupt handler of the External interrupt reception detector
__attribute__((__interrupt__))
static void eic_int_reception_detector(void)
{
	char temp_string[6];
	gpio_clr_gpio_pin(LED6);

	//Save vurrent time in temporary variable
	current_pulse = get_time();
	//adjust gain here.

	//Perform sample_burst, FFT an find dominating frequency and power
	FreqPower_t signal = check_signal();

	//assume valid pulse.calculate time and print data
	time_variable_t difference = calculate_time_diff(current_pulse, previous_pulse);
	if (difference.millisec < 0)
		difference = calculate_time_diff(current_pulse, previous_pulse);
	previous_pulse = current_pulse;

	//output the difference
	usart_write_line(USB_USART, "Pulse detected:\n space: ");
	short_to_char(temp_string, difference.millisec);
	usart_write_line(USB_USART, temp_string);
	usart_write_line(USB_USART, " ms, ");
	short_to_char(temp_string, difference.sec);
	usart_write_line(USB_USART, temp_string);
	usart_write_line(USB_USART, " s\n");

	//output the frequency and power
	usart_write_line(USB_USART, "Frequency: ");
	short_to_char(temp_string, signal.freq);
	usart_write_line(USB_USART, temp_string);
	usart_write_line(USB_USART, " kHz\n");
	usart_write_line(USB_USART, " Power: ");
	short_to_char(temp_string, signal.power);
	usart_write_line(USB_USART, temp_string);
	usart_write_line(USB_USART, "\n\n\n");

	gpio_set_gpio_pin(LED6);
	eic_clear_interrupt_line(&AVR32_EIC, EXT_INT_RECEPTION_LINE);
}




//Intitializes external interrupts
void init_EIC(void)
{
	// Structure holding the configuration parameters of the EIC module.
	eic_options_t eic_options_reception;

	  // Enable edge-triggered interrupt.
	eic_options_reception.eic_mode   = EIC_MODE_EDGE_TRIGGERED;
	  // Interrupt will trigger on rising edge.
	eic_options_reception.eic_edge  = EIC_EDGE_RISING_EDGE;
	  // Initialize in synchronous mode : interrupt is synchronized to the clock
	eic_options_reception.eic_async  = EIC_SYNCH_MODE;
	  // Set the interrupt line number.
	eic_options_reception.eic_line   = EXT_INT_RECEPTION_LINE;

	// Map the interrupt lines to the GPIO pins with the right peripheral functions.
	gpio_enable_module_pin(EXT_INT_RECEPTION_PIN, EXT_INT_RECEPTION_FUNCTION);

	Disable_global_interrupt();

	//register interrupt handler
	INTC_register_interrupt(&eic_int_reception_detector, EXT_INT_RECEPTION_IRQ, AVR32_INTC_INT0);

	// Init the EIC controller with the options
	eic_init(&AVR32_EIC, &eic_options_reception, 1);

	// Enable the chosen lines and their corresponding interrupt feature.
	eic_enable_line(&AVR32_EIC, eic_options_reception.eic_line);
	eic_enable_interrupt_line(&AVR32_EIC, eic_options_reception.eic_line);

	Enable_global_interrupt();
}
