/*
 * TC_functions.h
 *
 *  Created on: 22.jun.2009
 *      Author: Stian O. Moen
 */

#ifndef TC_FUNCTIONS_H_
#define TC_FUNCTIONS_H_

#include "config.h"
#include "tc.h"

//specify the frequency of FPBA
#define FPBA    F_CPU
//specify timer/counter channel to be used to trigger ADC conversion
#define TC_CHANNEL    0


//Prototypes

  void init_TC( void );
  void enable_sampling(void);
  void disable_sampling(void);

  extern volatile U32 tc_tick;
  extern volatile U16 print_sec;
  extern volatile avr32_tc_t *tc;

 // Options for waveform generation setting up the hardware signal to trigger
 // ADC conversions
    static const tc_waveform_opt_t WAVEFORM_OPT =
    {
      .channel  = TC_CHANNEL,                        // Channel selection.

      .bswtrg   = TC_EVT_EFFECT_NOOP,                // Software trigger effect on TIOB.
      .beevt    = TC_EVT_EFFECT_NOOP,                // External event effect on TIOB.
      .bcpc     = TC_EVT_EFFECT_NOOP,                // RC compare effect on TIOB.
      .bcpb     = TC_EVT_EFFECT_NOOP,                // RB compare effect on TIOB.

      .aswtrg   = TC_EVT_EFFECT_NOOP,                // Software trigger effect on TIOA.
      .aeevt    = TC_EVT_EFFECT_NOOP,                // External event effect on TIOA.
      .acpc     = TC_EVT_EFFECT_CLEAR,                // RC compare effect on TIOA: clear. this signal is used to trigger ADC conversion
      .acpa     = TC_EVT_EFFECT_SET,                // RA compare effect on TIOA: set.

      .wavsel   = TC_WAVEFORM_SEL_UP_MODE_RC_TRIGGER,// Waveform selection: Up mode with automatic trigger(reset) on RC compare.
      .enetrg   = FALSE,                             // External event trigger enable.
      .eevt     = 0,                                 // External event selection.
      .eevtedg  = TC_SEL_NO_EDGE,                    // External event edge selection.
      .cpcdis   = FALSE,                             // Counter disable when RC compare.
      .cpcstop  = FALSE,                             // Counter clock stopped with RC compare.

      .burst    = FALSE,                             // Burst signal selection.
      .clki     = FALSE,                             // Clock inversion.
      .tcclks   = TC_CLOCK_SOURCE_TC3				// Internal source clock 3, connected to fPBA / 8.
    };
#endif /* TC_FUNCTIONS_H_ */
