/*
FILE:			config.h
PROJECT:		Telemetry Buoy project
DESCRIPTION:	Includes configuration parameters
DATE:			17.06.09
AUTHOR:			Stian O. Moen
*/

#ifndef config_h
#define config_h

#include "usart.h"

//Specify the base operating frequency
#define F_CPU	60000000

//Specify the clock speed of the timer/counter used for sampling
#define F_TIM	15000000

//Specify the sampling frequency
#define F_SMP	57692

//specify the number of samples per burst
#define NUMBER_OF_SAMPLES 	64  //must be 6*n due to filter optimization

//specify maximum analogue gain
#define MAX_GAIN	178828

//specify the gain of the cascaded stages
#define GAIN1	25
#define GAIN2	625
#define GAIN3	25

//specify the number of steps for the digital potentiometers.
#define POT_RES		256


//Uncomment to select clock source
#define EXTERNAL_CRYSTAL	1
//#define EXTERNAL_CLOCK		1

//The RTC timer prescaler
#define RTC_PRESCALER	4 	//will provide the RTC counter to count milliseconds

//GPIO MAP DEFINES
//ADC signal input
#define SIGNAL_IN_PIN			AVR32_ADC_AD_0_PIN
#define SINGAL_IN_ADC_CHANNEL	0
#define SIGNAL_IN_ADC_FUNCTION	AVR32_ADC_AD_0_FUNCTION

//ADC signal level
#define SIGNAL_LEVEL_PIN		AVR32_ADC_AD_1_PIN
#define SIGNAL_LEVEL_CHANNEL	1
#define SIGNAL_LVEL_FUNCTION	AVR32_ADC_AD_1_FUNCTION

//ADC spare input
#define ADC_EXTRA_PIN			AVR32_ADC_AD_4_PIN
#define ADC_EXTRA_CHANNEL		4
#define ADC_EXTRA_FUNCTION		AVR32_ADC_AD_4_FUNCTION

//Reception detecor interrupt pin
#define EXT_INT_RECEPTION_PIN              AVR32_EIC_EXTINT_1_PIN
#define EXT_INT_RECEPTION_FUNCTION         AVR32_EIC_EXTINT_1_FUNCTION
#define EXT_INT_RECEPTION_LINE			   EXT_INT1
#define EXT_INT_RECEPTION_IRQ			   AVR32_EIC_IRQ_1

//SPI pin definitions
#  define SPI_MOSI_PIN         AVR32_SPI_MOSI_0_0_PIN
#  define SPI_MOSI_FUNCTION    AVR32_SPI_MOSI_0_0_FUNCTION
#  define SPI_MISO_PIN         AVR32_SPI_MISO_0_0_PIN
#  define SPI_MISO_FUNCTION    AVR32_SPI_MISO_0_0_FUNCTION
#  define SPI_SCK_PIN		   AVR32_SPI_SCK_0_0_PIN
#  define SPI_SCK_FUNCTION     AVR32_SPI_SCK_0_0_FUNCTION
#  define SPI_NPCS0_PIN        AVR32_SPI_NPCS_0_0_PIN
#  define SPI_NPCS0_FUNCTION   AVR32_SPI_NPCS_0_0_FUNCTION
#  define SPI_NPCS1_PIN        AVR32_SPI_NPCS_1_0_PIN
#  define SPI_NPCS1_FUNCTION   AVR32_SPI_NPCS_1_0_FUNCTION
#  define SPI_NPCS2_PIN        AVR32_SPI_NPCS_2_0_PIN
#  define SPI_NPCS2_FUNCTION   AVR32_SPI_NPCS_2_0_FUNCTION
#  define SPI_NPCS3_PIN        AVR32_SPI_NPCS_3_0_PIN
#  define SPI_NPCS3_FUNCTION   AVR32_SPI_NPCS_3_0_FUNCTION
#  define SPI_DATAFLASH_CS	   AVR32_PIN_PA08

//USB <--> USART definitions
#  define USB_USART               (&AVR32_USART1)
#  define USB_USART_RX_PIN        AVR32_USART1_RXD_0_0_PIN
#  define USB_USART_RX_FUNCTION   AVR32_USART1_RXD_0_0_FUNCTION
#  define USB_USART_TX_PIN        AVR32_USART1_TXD_0_0_PIN
#  define USB_USART_TX_FUNCTION   AVR32_USART1_TXD_0_0_FUNCTION

//PIN definitions
#define LED6	AVR32_PIN_PA27
#define LED5	AVR32_PIN_PA26
#define LED4	AVR32_PIN_PA22
#define LED3	AVR32_PIN_PA21
#define LED2	AVR32_PIN_PA20
#define LED1	AVR32_PIN_PA13

// USART options.
static const usart_options_t USART_OPTIONS =
  {
	.baudrate     = 9600,
	.charlength   = 8,
	.paritytype   = USART_NO_PARITY,
	.stopbits     = USART_1_STOPBIT,
	.channelmode  = USART_NORMAL_CHMODE
  };


#endif
