/*
FILE:			main.c
PROJECT:		Telemetry Buoy project
DESCRIPTION:	Main file for the project
DATE:			17.06.09
AUTHOR:			Stian O. Moen
*/

#include <avr32\io.h>
#include "gpio.h"
#include "usart.h"
#include "pm.h"
#include "USART_functions.h"
#include "config.h"
#include "CLOCK_functions.h"
#include "stdio.h"
#include "tc.h"
#include "TC_functions.h"
#include "adc.h"
#include "ADC_functions.h"
#include "dsp.h"
#include "DSP_functions.h"
#include "intc.h"
#include "dsp_debug.h"
#include "SPI_functions.h"
#include "spi.h"
#include "rtc.h"
#include "RTC_functions.h"
#include "eic.h"
#include "EIC_functions.h"
#include "TEST_functions.h"

void display_level(unsigned short level);

int main(void) {

	//Initialize modules
	INTC_init_interrupts();
 	init_clock();
	init_USART();
	init_ADC();
	init_TC();
	init_SPI();
	init_RTC();
	init_EIC();


	usart_write_line(USB_USART, "\n\n *** Telemetry Buoy Running ***\n");

	//set reception detector threshold to 1 V.
	set_threshold(80);

	//set variable gain amplifier gain to 2000, or actually 380 due to unlinearity
	set_gain(2000);

	while(TRUE);


}


//function outputs the signal level on the LEDS as a bar graph
void display_level(unsigned short level)
{
	char leds = (level/1024 + 0.5);

	gpio_set_gpio_pin(LED6);
	gpio_set_gpio_pin(LED5);
	gpio_set_gpio_pin(LED4);
	gpio_set_gpio_pin(LED3);
	gpio_set_gpio_pin(LED2);
	gpio_set_gpio_pin(LED1);

	if (leds >= 1)
		gpio_clr_gpio_pin(LED1);
	if (leds >= 2)
		gpio_clr_gpio_pin(LED2);
	if (leds >= 3)
		gpio_clr_gpio_pin(LED3);
	if (leds >= 4)
		gpio_clr_gpio_pin(LED4);
	if (leds >= 5)
		gpio_clr_gpio_pin(LED5);
	if (leds >= 6)
		gpio_clr_gpio_pin(LED6);

}
