%Script that gives the bode responce of chebychev or Butterworth filter
%Implemented as Sallen & Key configuration. Script will calculate all
%Component values according to the crossover frequency and gain settings.
clc
clear all

%desired lower corner frequency [Hz]
f0 = 60000;

%desired higher corner frequency [Hz]
f1 = 80000;

%desired passband gain per amplifier
k =2.000001;

%low pass filter order
n_l = 4;

%high pass filter order
n_h = 4;


%Uncomment the poles to use

%calculate general (w0 = 1) lowpass butterworth pole positions
all_poles = roots([(-1)^n_l, zeros(1,2*n_l-1),1]);
negative_real_poles = all_poles(find(real(all_poles)<0));
den = poly(negative_real_poles);

%chebychev poles with 3dB rippel
%negative_real_poles = [-0.0340675444 + 0.3785869383i
%                      -0.0340675444 - 0.3785869383i
%                       -0.0822463277 + 0.1568158444i
%                       -0.0822463277 - 0.1568158444i];
                       
%chebychev poles with 1 dB rippel
negative_real_poles = [ -0.0558133907 + 0.3933445644i
                        -0.0558133907 - 0.3933445644i
                        -0.1347454448 + 0.1629286533i
                        -0.1347454448 - 0.1629286533i];
	 



%calculate desired w0/Q for filter tranferfunction one and 2
w0_Q1 = -(negative_real_poles(1)+negative_real_poles(2));
w0_Q2 = -(negative_real_poles(3)+negative_real_poles(4));

%plot general low pass function
%H_butt = tf([k*k],den);
%bode(H_butt);


%plot general high pass function
%H_butt = tf([k*k 0 0 0 0],den)
%bode(H_butt)
%hold on

%%
% ******* LOW PASS CALCULATIONS *******

%choose C1=C2=C3=C4=C
C = 1;%47e-12;
C1 = C;
C2 = C;
C3 = C;
C4 = C;

%calcualte Resistor values for w0 = 1 for first sallen key circuit
w0 = 1; %do not change!
Q1  =  w0/w0_Q1;
%R1 = (-1/Q1+sqrt(1/Q1^2-4*(C1+C2*(1-k))*1/C2))/(2*(C1+C2*(1-k)))
R1 = 1/2*(w0*C2-sqrt(w0^2*C2^2-4*Q1^2*C2*C1-4*Q1^2*C2^2+4*Q1^2*C2^2*k))/(Q1*C2*(C1+C2-C2*k));
R2 = 1/(R1*C1*C2);

%calcualte Resistor values for w0 = 1 for second sallen key circuit
Q2  = w0/w0_Q2;
R3 = 1/2*(w0*C4-sqrt(w0^2*C4^2-4*Q2^2*C4*C3-4*Q2^2*C3^2+4*Q2^2*C4^2*k))/(Q2*C4*(C3+C4-C4*k));
R4 = 1/(R3*C3*C4);

%define lowpass filter transferfunction
nom1 = [k];
den1 = [R1*R2*C1*C2 (R1*C1+R2*C1 + R1*C2*(1-k)) 1];

nom2 = [k];
den2 = [R3*R4*C3*C4 (R3*C3+R4*C3 + R3*C4*(1-k)) 1];

%Calculate nominal low pass transfer function (i.e. w0 = 1)
H_l1 = tf(nom1,den1);
H_l2 = tf(nom2,den2);
H_l  = H_l1*H_l2

%scale values to get crossover at f0

C = C/(f1*2*pi); %scale to freqency
C_desired = 47e-12;

%scale to stadard capacitor value
factor  = C/C_desired
C = C/factor     %scale to resistors

C1 = C
C2 = C
C3 = C
C4 = C

R1 = R1*factor
R2 = R2*factor
R3 = R3*factor
R4 = R4*factor



%Calculate actual transferfunction
nom1a = [k];
den1a = [R1*R2*C1*C2 (R1*C1+R2*C1 + R1*C2*(1-k)) 1];

nom2a = [k];
den2a = [R3*R4*C3*C4 (R3*C3+R4*C3 + R3*C4*(1-k)) 1];

H_la1 = tf(nom1a,den1a);
H_la2 = tf(nom2a,den2a);
H_a  = H_la1*H_la2;



%%
%******* HIGH PASS CALCULATIONS *******

%choose C1=C2=C3=C4=C
C = 1;%47e-12;
C5 = C;
C6 = C;
C7 = C;
C8 = C;

%calcualte Resistor values for w0 = 1 for third sallen key circuit
w0 = 1; %do not change!
Q1  =  w0/w0_Q1
R6 = 1/2*(w0*C5+sqrt(w0^2*C5^2-4*Q1^2*C6*C5+4*Q1^2*C6*C5*k-4*C5^2*Q1^2+4*C5^2*Q1^2*k))/(C5*Q1*(C6+C5));
R5 = 1/(R6*C5*C6);

%calcualte Resistor values for w0 = 1 for fourth sallen key circuit
Q2  = w0/w0_Q2
Q1  = w0/w0_Q1
R8 = 1/2*(w0*C7+sqrt(w0^2*C7^2-4*Q2^2*C8*C7+4*Q2^2*C8*C7*k-4*C7^2*Q2^2+4*C7^2*Q2^2*k))/(C7*Q2*(C8+C7));
R7 = 1/(R8*C7*C8);


%define highpass filter transferfunction
nom3 = [k*R5*R6*C5*C6 0 0];
den3 = [R5*R6*C5*C6 (R6*C6 + R6*C5 + R5*C6*(1-k)) 1];

nom4 = [k*R7*R8*C7*C8 0 0];
den4 = [R7*R8*C7*C8 (R8*C8 + R8*C7 + R7*C8*(1-k)) 1];

%Plot nominal transfer function (i.e. w0 = 1)
H_h1 = tf(nom3,den3)
H_h2 = tf(nom4,den4)
H_h  = H_h1*H_h2


%scale values to get crossover at f0
%factor = 100e3; %component scale factor
C = C/(f0*2*pi); %scale to freqency
C_desired = 47e-12;

%scale to stadard capacitor value
factor  = C/C_desired
C = C/factor     %scale to resistors

C5 = C
C6 = C
C7 = C
C8 = C

R5 = R5*factor
R6 = R6*factor
R7 = R7*factor
R8 = R8*factor


%Calculate actual high pass transferfunction
nom3a = [k*R5*R6*C5*C6 0 0];
den3a = [R5*R6*C5*C6 (R6*C6 + R6*C5 + R5*C6*(1-k)) 1];

nom4a = [k*R7*R8*C7*C8 0 0];
den4a = [R7*R8*C7*C8 (R8*C8 + R8*C7 + R7*C8*(1-k)) 1];

H_ha1 = tf(nom3a,den3a);
H_ha2 = tf(nom4a,den4a);
H_ha   = H_ha1*H_ha2;

%calculate total band pass transferfunction

H = H_a*H_ha;

%Bodeplots
P = bodeoptions;
P.PhaseVisible = 'off';
P.FreqUnits = 'Hz';
P.Xlim = [1000 500000];


figure(1)
P.Title.String = 'Low pass transfer function';
subplot(2,2,1);
bode(H_a,P);

P.Title.String = 'High pass transfer function';
subplot(2,2,2);
bode(H_ha,P);

P.Title.String = 'Combined band pass transfer function';
figure(2);
bode(H,P);

%%
%figure(1);
%subplot(2,2,1);
%bode(Hni,P);
%P.Title.String = 'Active low pass filter with gain';
%subplot(2,2,2);
%title('Active Low Pass');
%bode(G,P);
%P.Title.String = 'Combined potentiometer, HP and LP';
%subplot(2,2,3);
%title('Combined one link');
%bode(G*Hni,P);
%bode(Hp*Hlp,P); only for testing
%subplot(2,2,4);
%title('Full AGC responce');
%bode(Hni*G*Hni*G*Hni*G*Hp*G,P);


